###----------------------------------------------------------------------------
### Logit Regression with ungrouped data, Example 15.5
###----------------------------------------------------------------------------

## Load the data (this is the ungrouped data)
bankData <- read.table("Example15.5.csv", header = TRUE)

X <- as.matrix(cbind(1, bankData[, c("Balance", "ATM", "Interest")]))
y <- as.matrix(bankData[, "Debit", drop = FALSE])

## Estimate the model
bankModel <- glm(Debit~Balance+ATM+Interest,
                 family = binomial(link = logit),
                 data = bankData)

## Summarize the model
summary(bankModel)



###----------------------------------------------------------------------------
### Probit Regression with ungrouped data, Example 15.5,  continued
###----------------------------------------------------------------------------

## Estimate the model
bankModelProbit <- glm(Debit~Balance+ATM+Interest,
                 family = binomial(link = probit),
                 data = bankData)

## Summarize the model
summary(bankModelProbit)

###----------------------------------------------------------------------------
### Probit Regression with grouped data,  Example 15.6
###----------------------------------------------------------------------------

## The housing and income data (grouped)
house <- "
Income	N	n
6	40	8
8	50	12
10	60	18
13	80	28
15	100	45
20	70	36
25	65	39
30	50	33
35	40	30
40	25	20"
houseData <- read.table(textConnection(house), header = TRUE)
n <- houseData[, "n"]
N <- houseData[, "N"]
Income <- houseData[, "Income"]

## Obtain the estimated P
PHat <- n/N

## Inverse from the CDF to PDF
IHat <- qnorm(p = PHat)

## Regression
houseModelProbit <- lm(IHat~Income)
summary(houseModelProbit)

## Predict the probability of owing a house
IFitted <- houseModelProbit$fitted.values
PFitted <- pnorm(IFitted)

cbind(PHat, PFitted)

## Question, how do we do it with student-t assumption

###----------------------------------------------------------------------------
### Poisson Regression,  Example 15.8
###----------------------------------------------------------------------------

## Load the data
fallData <- read.table("Example15.8.csv", header = TRUE)

X <- as.matrix(cbind(1, fallData[, 2:5]))
y <- as.matrix(fallData[, 1, drop = FALSE])

## Fit the Poisson model with maximum likelihood method
fallModel <- glm(falls~education+gender+balance+strength,
                 family = poisson(link = log), data = fallData)

## Summary of the model
summary(fallModel)

## What is the predicted mean falls for each observation
muHat <- exp(X%*%betaHat)
fallModel$fitted.values ## or obtained in this way


## What is the probability of each individual has 3 exactly falls
betaHat <- matrix(fallModel$coefficients)
muHat <- exp(X%*%betaHat)
p <- muHat^3*exp(-muHat)/factorial(3) # or calculate in this way
p <- dpois(3, muHat)

## What is the probability of each individual has no more than three falls
p3 <- (muHat^0*exp(-muHat)/factorial(0) +
       muHat^1*exp(-muHat)/factorial(1) +
       muHat^2*exp(-muHat)/factorial(2) +
       muHat^3*exp(-muHat)/factorial(3)) # or we obtain them in this way

p3 <- ppois(3, muHat)

## What is the probability of each individuals has at least three falls?
